==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/dochazka/dennivysledkycontroller.php <==
<?php
/**
 * stanislav.elbl, 24.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MVC\Controller;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\TextManager;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;

class DenniVysledkyController implements Controller
{
    /** @var  Database */
    var $database;


    /**
     * DenniVysledkyController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');
        HtmlHeaders::getInstance() ->addScript('script/dochazka.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');
        HtmlHeaders::getInstance() ->setTitle( TextManager::_('RON_Portal') . ' - ' . TextManager::_('Dochazka_title'));

        if (!RonPortalSettings::getValue(DenniVysledkyBrowser::SETTINGS_SLOUPCE)) {
            throw new \Exception( TextManager::_('Neni_nastaveni_sloupcu_tabulky') );
        }

        $b = new DenniVysledkyBrowser($this ->database, $action == 'dennivysledkyvariantni');

        if (isset($_POST['editacedennich'])) {
            if ( $b ->ulozDenniVysledky() ) {
                $params = '?menuid=dennivysledky&idpp=' . RonPortalSession::vybranaOsoba() . '&obdobi=' . DateUtils::dateToUrlString(RonPortalSession::obdobi());
                if (isset($_POST['dialogschvaleni']) && $_POST['dialogschvaleni']) {
                    $params .= '&dialogschvaleni=1';
                }

                return new Redirect(null, $params );
            }
        }

        $b ->load();

        if (isset($_GET['dialogschvaleni'])  &&  $_GET['dialogschvaleni']) {
            $schvaleniView = new SchvaleniView($this ->database, true);
            $schvaleniView ->redirectUrl = '?menuid=dennivysledky&idpp=' . RonPortalSession::vybranaOsoba() . '&obdobi=' . DateUtils::dateToUrlString(RonPortalSession::obdobi());
            Model::addViewObject($schvaleniView);
        }

        return $b;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/dochazka/dennivysledkycontroller.php <==
<?php
/**
 * stanislav.elbl, 24.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MVC\Controller;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\TextManager;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;

class DenniVysledkyController implements Controller
{
    /** @var  Database */
    var $database;


    /**
     * DenniVysledkyController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');
        HtmlHeaders::getInstance() ->addScript('script/dochazka.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');
        HtmlHeaders::getInstance() ->setTitle( TextManager::_('RON_Portal') . ' - ' . TextManager::_('Dochazka_title'));

        if (!RonPortalSettings::getValue(DenniVysledkyBrowser::SETTINGS_SLOUPCE)) {
            throw new \Exception( TextManager::_('Neni_nastaveni_sloupcu_tabulky') );
        }

        $b = new DenniVysledkyBrowser($this ->database, $action == 'dennivysledkyvariantni');

        if (isset($_POST['editacedennich'])) {
            if ( $b ->ulozDenniVysledky() ) {
                $params = '?menuid=dennivysledky&idpp=' . RonPortalSession::vybranaOsoba() . '&obdobi=' . DateUtils::dateToUrlString(RonPortalSession::obdobi());
                if (isset($_POST['dialogschvaleni']) && $_POST['dialogschvaleni']) {
                    $params .= '&dialogschvaleni=1';
                }

                return new Redirect(null, $params );
            }
        }

        $b ->load();

        if (isset($_GET['dialogschvaleni'])  &&  $_GET['dialogschvaleni']) {
            $schvaleniView = new SchvaleniView($this ->database, true);
            $schvaleniView ->setRedirectUrl('?menuid=dennivysledky&idpp=' . RonPortalSession::vybranaOsoba() . '&obdobi=' . DateUtils::dateToUrlString(RonPortalSession::obdobi()));
            Model::addViewObject($schvaleniView);
        }

        return $b;
    }
}
